import * as d3 from 'd3';

function renderData(dataElements) {

    let width = 700;
    let height = 600;
    let offset = 200;
    let topOffset = 100;

    dataElements = dataElements.sort((a, b) => b['Top_Films_1995-2021'] - a['Top_Films_1995-2021']);

    let distrFilms = dataElements.map(o => parseInt(o['Top_Films_1995-2021']));
    let distributors = dataElements.map(o => o['Distributor']);
    const maxVal = d3.max(distrFilms);
    let ind = [];
    for (let i = 0; i < maxVal + 2; i++) { ind[i] = i; }

    const len = 2 * maxVal;

    let x = d3.scaleLinear()
        .domain([0, len])
        .range([0, width]);

    let y = d3.scaleBand()
        .domain(d3.range(distributors.length))
        .range([0, 30 * distributors.length])

    const svg = d3.select("body").append("svg")
        .attr("width", width)
        .attr("height", height);

    svg.append("text")
        .attr("fill", "black")
        .attr("x", offset - 10)
        .attr("y", "40")
        .style("font-size", "18px")
        .text("Most successful distributors by movie of the year.");

    svg.append("text")
        .attr("fill", "black")
        .attr("x", offset - 10)
        .attr("y", "60")
        .style("font-size", "12px")
        .text("1995 - 2021 years.");

    const net = svg.append("g")
        .selectAll("line")
        .data(ind)
        .join("line")
        .attr("transform", () => `translate(${offset}, 0)`)
        .attr("stroke", "gray")
        .attr("x1", (v) => x(v))
        .attr("y1", "85")
        .attr("x2", (v) => x(v))
        .attr("y2", "312");

    const netText = svg.append("g")
        .selectAll("text")
        .data(ind)
        .join("text")
        .attr("text-anchor", "middle")
    		.style("font-size", "14px")
        .attr("fill", "black")
        .attr("dy", "0.35em")
        .attr("transform", () => `translate(${offset}, 0)`)
        .attr("x", (v) => x(v))
        .attr("y", "300")
        .text((v, i) => ind[i]);

    svg.append("line")
        .attr("stroke", "gray")
        .attr("x1", offset)
        .attr("y1", "312")
        .attr("x2", offset + (maxVal + 2) * 28)
        .attr("y2", "312");

    const bar = svg.selectAll("g")
        .data(distrFilms)
        .join("g")
        .attr("transform", (f, m) => `translate(0, ${y(m)})`);

    bar.append("rect")
        .attr("fill", "steelblue")
        .attr("width", x)
        .attr("height", y.bandwidth() - 1)
        .attr("x", offset)
        .attr("y", topOffset);

    bar.append("text")
        .attr("text-anchor", "end")
  			.style("font-size", "14px")
        .attr("fill", "black")
        .attr("x", offset - 5)
        .attr("y", topOffset + (y.bandwidth() - 1) / 2)
        .attr("dy", "0.35em")
        .text((d, i) => distributors[i]);

    svg.append("text")
        .attr("fill", "black")
        .attr("x", offset + 150)
        .attr("y", "370")
        .style("font-size", "14px")
        .text("Movies");

    svg.append("text")
        .attr("fill", "black")
        .attr("x", "45")
        .attr("y", "40")
  			.attr("transform", "translate(30, 300) rotate(270)")
        .style("font-size", "14px")
        .text("Distributor");
}

d3.csv(
    "https://raw.githubusercontent.com/olga-kondr/olga-kondr.github.io/main/csv/top_films_count.csv"
).then(data => renderData(data));